==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nell&apos;esplora risorse</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Pulisci log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Sicuro di voler ripulire il log?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Oggi</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 giorni</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 settimana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mese</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mesi</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Esporta</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Esporta</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergenza</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avviso</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Avviso</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Avvio</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molto critico</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traccia</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Esportazione in corso...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Esportazione riuscita</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Esportazione fallita</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Esporta file</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periodo: </translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Livello: </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista App: </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Stato: </translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utente: </translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID: </translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Azione: </translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registrazione riavvio</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Registrazione spegnimento</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Registrazione login</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>avviso</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergenza</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Avviso</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traccia</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molto critico</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Il file Log è vuoto</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Log Viewer</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer è uno strumento utile per visualizzare i log di sistema.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Livello</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Processi</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data ed ora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo evento</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Livello: </translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Processo:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data ed ora: </translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info: </translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utente: </translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID: </translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data ed ora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>System Log</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel Log</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot Log</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg Log</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Log di Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg Log</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>App Log</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Eventi di Avvio&amp;Spegnimento</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Log DNF</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nell&apos;esplora risorse</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Pulisci log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Sicuro di voler ripulire il log?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Oggi</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 giorni</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 settimana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mese</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mesi</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Esporta</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergenza</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avviso</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Avviso</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Avvio</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molto critico</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traccia</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Autenticazione identità utente</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Controllo accesso discrezionale</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Controllo accesso obbligatorio</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Remoto</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Verifica documento</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altro</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Esportazione in corso...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Esportazione riuscita</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Esportazione fallita</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Esporta file</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periodo: </translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Livello: </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Stato: </translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utente: </translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID: </translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Azione: </translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registrazione riavvio</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Registrazione spegnimento</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Registrazione login</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Tipo verifica:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>avviso</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergenza</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Avviso</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traccia</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molto critico</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Il file Log è vuoto</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Log Viewer</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer è uno strumento utile per visualizzare i log di sistema.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Livello</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Processi</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data ed ora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo evento</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Livello: </translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Processo:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data ed ora: </translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info: </translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utente: </translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID: </translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Data modifica</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data ed ora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>System Log</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel Log</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot Log</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg Log</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Log di Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg Log</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>App Log</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Eventi di Avvio&amp;Spegnimento</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Log DNF</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Altri log</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Log personalizzato</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Log di verifica</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Non hai il permesso per visualizzarlo</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Intervallo di aggiornamento</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sec</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Nessun aggiornamento</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Esporta tutto</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Aggiorna ora</translation>
    </message>
</context>
</TS>
